# spelling-bee-cheat 👑🐝📚

This package is for cheating at the [NYT Spelling Bee puzzle](https://www.nytimes.com/puzzles/spelling-bee). The exact feature set hasn't been decided yet. One thing that works well is the system for archiving data about previous days' puzzles. One interesting unfinished feature is the ability to suggest words to guess using an n-gram character model in lieu of a dictionary. There is also some code in here for filtering dictionaries according to the game rules. You can't use this package to play Spelling Bee.


## Spelling Bee Rules

The goal of Spelling Bee is to find as many words as possible that meet the following criteria:

 1. contains only letters from the 7 given letters
 1. contains the center letter at least once
 1. has at least 4 letters


## Related Packages

I found three related packages on PyPI as of 2023-05-14:

| PyPI                                      | GitHub                                                   | License |
| ----------------------------------------- | -------------------------------------------------------- | ------- |
| https://pypi.org/project/buzzoff/         | https://github.com/spagh-eddie/buzzoff                   | MIT     |
| https://pypi.org/project/textual-bee/     | https://github.com/torshepherd/textual-bee               | MIT     |
| https://pypi.org/project/spelling-bee-mh/ | https://github.com/mharty3/spelling_bee_package_tutorial | MIT     |

You can browse packages tagged with `spelling-bee` on Github [here](https://github.com/topics/spelling-bee). And, you can find even more with a search engine.
